binman: Tidy up pylint warnings in comp_util

Tweak some naming and comments to resolve these. Use WriteFile() to write
the file.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/tools/binman/comp_util.py b/tools/binman/comp_util.py
index 541e191..7e741cb 100644
--- a/tools/binman/comp_util.py
+++ b/tools/binman/comp_util.py
@@ -8,7 +8,7 @@
 
 from patman import tools
 
-def Compress(indata, algo, with_header=True):
+def compress(indata, algo, with_header=True):
     """Compress some data using a given algorithm
 
     Note that for lzma this uses an old version of the algorithm, not that
@@ -21,11 +21,11 @@
     called from multiple threads.
 
     Args:
         indata: Input data to compress
         algo: Algorithm to use ('none', 'gzip', 'lz4' or 'lzma')
 
     Returns:
-        Compressed data
+        bytes: Compressed data
     """
     if algo == 'none':
         return indata
@@ -51,7 +51,7 @@
         data = hdr + data
     return data
 
-def Decompress(indata, algo, with_header=True):
+def decompress(indata, algo, with_header=True):
     """Decompress some data using a given algorithm
 
     Note that for lzma this uses an old version of the algorithm, not that
@@ -61,11 +61,11 @@
     directory to be previously set up, by calling PrepareOutputDir().
 
     Args:
         indata: Input data to decompress
         algo: Algorithm to use ('none', 'gzip', 'lz4' or 'lzma')
 
     Returns:
-        Compressed data
+        (bytes) Compressed data
     """
     if algo == 'none':
         return indata
@@ -73,8 +73,7 @@
         data_len = struct.unpack('<I', indata[:4])[0]
         indata = indata[4:4 + data_len]
     fname = tools.GetOutputFilename('%s.decomp.tmp' % algo)
-    with open(fname, 'wb') as fd:
-        fd.write(indata)
+    tools.WriteFile(fname, indata)
     if algo == 'lz4':
         data = tools.Run('lz4', '-dc', fname, binary=True)
     elif algo == 'lzma':
@@ -21,11 +21,11 @@
 
     Args:
-        indata: Input data to compress
-        algo: Algorithm to use ('none', 'gzip', 'lz4' or 'lzma')
+        indata (bytes): Input data to compress
+        algo (str): Algorithm to use ('none', 'gzip', 'lz4' or 'lzma')
 
     Returns:
@@ -61,11 +61,11 @@
 
     Args:
-        indata: Input data to decompress
-        algo: Algorithm to use ('none', 'gzip', 'lz4' or 'lzma')
+        indata (bytes): Input data to decompress
+        algo (str): Algorithm to use ('none', 'gzip', 'lz4' or 'lzma')
 
     Returns: